emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r103904: lisp/autorevert.el: Use `rem


From: Juanma Barranquero
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r103904: lisp/autorevert.el: Use `remote-file-name-inhibit-cache'.
Date: Wed, 13 Apr 2011 16:27:41 +0200
User-agent: Bazaar (2.3.1)

------------------------------------------------------------
revno: 103904
committer: Juanma Barranquero <address@hidden>
branch nick: trunk
timestamp: Wed 2011-04-13 16:27:41 +0200
message:
  lisp/autorevert.el: Use `remote-file-name-inhibit-cache'.
  
  * autorevert.el (auto-revert-handler):
    Bind `remote-file-name-inhibit-cache', not `tramp-cache-inhibit-cache',
    which was removed in revno:101730 (2010-10-02).
    Don't quote lambda.
modified:
  lisp/ChangeLog
  lisp/autorevert.el
=== modified file 'lisp/ChangeLog'
--- a/lisp/ChangeLog    2011-04-13 02:16:42 +0000
+++ b/lisp/ChangeLog    2011-04-13 14:27:41 +0000
@@ -1,5 +1,10 @@
 2011-04-13  Juanma Barranquero  <address@hidden>
 
+       * autorevert.el (auto-revert-handler):
+       Bind `remote-file-name-inhibit-cache', not `tramp-cache-inhibit-cache',
+       which was removed in revno:101730 (2010-10-02).
+       Don't quote lambda.
+
        * image-mode.el (image-transform-set-scale):
        Fix change in revno:103877 (2011-04-09).
 

=== modified file 'lisp/autorevert.el'
--- a/lisp/autorevert.el        2011-02-20 00:09:28 +0000
+++ b/lisp/autorevert.el        2011-04-13 14:27:41 +0000
@@ -434,9 +434,9 @@
                     (file-readable-p buffer-file-name)
                     (if auto-revert-tail-mode
                         ;; Tramp caches the file attributes.  Setting
-                        ;; `tramp-cache-inhibit' forces Tramp to
-                        ;; reread the values.
-                        (let ((tramp-cache-inhibit-cache t))
+                        ;; `remote-file-name-inhibit-cache' forces Tramp
+                        ;; to reread the values.
+                        (let ((remote-file-name-inhibit-cache t))
                           (/= auto-revert-tail-pos
                               (setq size
                                     (nth 7 (file-attributes
@@ -460,10 +460,10 @@
        (when buffer-file-name
          (setq eob (eobp))
          (walk-windows
-          #'(lambda (window)
-              (and (eq (window-buffer window) buffer)
-                   (= (window-point window) (point-max))
-                   (push window eoblist)))
+          (lambda (window)
+            (and (eq (window-buffer window) buffer)
+                 (= (window-point window) (point-max))
+                 (push window eoblist)))
           'no-mini t))
        (if auto-revert-tail-mode
            (auto-revert-tail-handler size)


reply via email to

[Prev in Thread] Current Thread [Next in Thread]